pub struct InferenceAdvisory {
pub batch_id: String,
pub source_envelope_id: String,
pub graph_hash: String,
pub execution_mode: String,
pub iteration_count: u32,
pub message_count: usize,
pub degradation_markers: Vec<String>,
pub oracle_mode: String,
pub oracle_supported: bool,
pub satisfied_constraint_count: usize,
pub advisory_only: bool,
pub degraded_reason: Option<String>,
}Fields
batch_id: Stringsource_envelope_id: Stringgraph_hash: Stringexecution_mode: Stringiteration_count: u32message_count: usizedegradation_markers: Vec<String>oracle_mode: Stringoracle_supported: boolsatisfied_constraint_count: usizeadvisory_only: booldegraded_reason: Option<String>Trait Implementations
Sourceimpl Clone for InferenceAdvisory
impl Clone for InferenceAdvisory
Sourcefn clone(&self) -> InferenceAdvisory
fn clone(&self) -> InferenceAdvisory
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InferenceAdvisory
impl Debug for InferenceAdvisory
Sourceimpl<'de> Deserialize<'de> for InferenceAdvisory
impl<'de> Deserialize<'de> for InferenceAdvisory
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InferenceAdvisory
Sourceimpl JsonSchema for InferenceAdvisory
impl JsonSchema for InferenceAdvisory
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InferenceAdvisory
impl PartialEq for InferenceAdvisory
Sourcefn eq(&self, other: &InferenceAdvisory) -> bool
fn eq(&self, other: &InferenceAdvisory) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InferenceAdvisory
impl Serialize for InferenceAdvisory
impl StructuralPartialEq for InferenceAdvisory