pub struct InferenceExplanation {Show 22 fields
pub batch_id: String,
pub source_envelope_id: String,
pub graph_hash: String,
pub execution_mode: String,
pub stop_reason: String,
pub stage_kinds: Vec<String>,
pub degradation_markers: Vec<String>,
pub witness_count: usize,
pub witness_node_ids: Vec<String>,
pub certificate_count: usize,
pub certificate_node_ids: Vec<String>,
pub residual_count: usize,
pub residual_micros: Vec<u64>,
pub syndrome_signatures: Vec<String>,
pub calibration_caveats: Vec<String>,
pub refutation_outcome: String,
pub causal_refutation_outcome: String,
pub minimal_perturbation_outcome: String,
pub oracle_mode: String,
pub oracle_supported: bool,
pub advisory_only: bool,
pub degraded_reason: Option<String>,
}Fields
batch_id: Stringsource_envelope_id: Stringgraph_hash: Stringexecution_mode: Stringstop_reason: Stringstage_kinds: Vec<String>degradation_markers: Vec<String>witness_count: usizewitness_node_ids: Vec<String>certificate_count: usizecertificate_node_ids: Vec<String>residual_count: usizeresidual_micros: Vec<u64>syndrome_signatures: Vec<String>calibration_caveats: Vec<String>refutation_outcome: Stringcausal_refutation_outcome: Stringminimal_perturbation_outcome: Stringoracle_mode: Stringoracle_supported: booladvisory_only: booldegraded_reason: Option<String>Trait Implementations
Sourceimpl Clone for InferenceExplanation
impl Clone for InferenceExplanation
Sourcefn clone(&self) -> InferenceExplanation
fn clone(&self) -> InferenceExplanation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InferenceExplanation
impl Debug for InferenceExplanation
Sourceimpl<'de> Deserialize<'de> for InferenceExplanation
impl<'de> Deserialize<'de> for InferenceExplanation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InferenceExplanation
Sourceimpl JsonSchema for InferenceExplanation
impl JsonSchema for InferenceExplanation
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InferenceExplanation
impl PartialEq for InferenceExplanation
Sourcefn eq(&self, other: &InferenceExplanation) -> bool
fn eq(&self, other: &InferenceExplanation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InferenceExplanation
impl Serialize for InferenceExplanation
impl StructuralPartialEq for InferenceExplanation