pub struct RiskGateDecision {
pub batch_id: String,
pub source_envelope_id: String,
pub status: String,
pub reasons: Vec<String>,
pub advisory_only: bool,
pub degraded_reason: Option<String>,
}Fields
batch_id: Stringsource_envelope_id: Stringstatus: Stringreasons: Vec<String>advisory_only: booldegraded_reason: Option<String>Trait Implementations
Sourceimpl Clone for RiskGateDecision
impl Clone for RiskGateDecision
Sourcefn clone(&self) -> RiskGateDecision
fn clone(&self) -> RiskGateDecision
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RiskGateDecision
impl Debug for RiskGateDecision
Sourceimpl<'de> Deserialize<'de> for RiskGateDecision
impl<'de> Deserialize<'de> for RiskGateDecision
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RiskGateDecision
Sourceimpl JsonSchema for RiskGateDecision
impl JsonSchema for RiskGateDecision
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RiskGateDecision
impl PartialEq for RiskGateDecision
Sourcefn eq(&self, other: &RiskGateDecision) -> bool
fn eq(&self, other: &RiskGateDecision) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RiskGateDecision
impl Serialize for RiskGateDecision
impl StructuralPartialEq for RiskGateDecision