pub struct CompiledObligationRuntimeViewV1 {
pub schema_version: String,
pub compiled_obligation_set_id: CompiledObligationSetId,
pub effective_constitution_id: EffectiveConstitutionId,
pub required_approvals: Vec<String>,
pub required_checks: Vec<String>,
pub required_monitors: Vec<String>,
pub required_disclosure_obligations: Vec<String>,
pub required_post_hoc_review_obligations: Vec<String>,
pub unresolved_dependency_refs: Vec<String>,
pub effect_eligibility_summary: String,
}Fields
schema_version: Stringcompiled_obligation_set_id: CompiledObligationSetIdeffective_constitution_id: EffectiveConstitutionIdrequired_approvals: Vec<String>required_checks: Vec<String>required_monitors: Vec<String>required_disclosure_obligations: Vec<String>required_post_hoc_review_obligations: Vec<String>unresolved_dependency_refs: Vec<String>effect_eligibility_summary: StringTrait Implementations
Sourceimpl Clone for CompiledObligationRuntimeViewV1
impl Clone for CompiledObligationRuntimeViewV1
Sourcefn clone(&self) -> CompiledObligationRuntimeViewV1
fn clone(&self) -> CompiledObligationRuntimeViewV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CompiledObligationRuntimeViewV1
impl<'de> Deserialize<'de> for CompiledObligationRuntimeViewV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompiledObligationRuntimeViewV1
Sourceimpl JsonSchema for CompiledObligationRuntimeViewV1
impl JsonSchema for CompiledObligationRuntimeViewV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompiledObligationRuntimeViewV1
impl PartialEq for CompiledObligationRuntimeViewV1
Sourcefn eq(&self, other: &CompiledObligationRuntimeViewV1) -> bool
fn eq(&self, other: &CompiledObligationRuntimeViewV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CompiledObligationRuntimeViewV1