pub struct CompositionConflictRuntimeViewV1 {
pub schema_version: String,
pub composition_conflict_set_id: CompositionConflictSetId,
pub effective_constitution_id: Option<EffectiveConstitutionId>,
pub blocking: bool,
pub conflict_keys: Vec<String>,
pub review_paths: Vec<String>,
pub admissible_exception_classes: Vec<String>,
}Fields
schema_version: Stringcomposition_conflict_set_id: CompositionConflictSetIdeffective_constitution_id: Option<EffectiveConstitutionId>blocking: boolconflict_keys: Vec<String>review_paths: Vec<String>admissible_exception_classes: Vec<String>Trait Implementations
Sourceimpl Clone for CompositionConflictRuntimeViewV1
impl Clone for CompositionConflictRuntimeViewV1
Sourcefn clone(&self) -> CompositionConflictRuntimeViewV1
fn clone(&self) -> CompositionConflictRuntimeViewV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CompositionConflictRuntimeViewV1
impl<'de> Deserialize<'de> for CompositionConflictRuntimeViewV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompositionConflictRuntimeViewV1
Sourceimpl JsonSchema for CompositionConflictRuntimeViewV1
impl JsonSchema for CompositionConflictRuntimeViewV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompositionConflictRuntimeViewV1
impl PartialEq for CompositionConflictRuntimeViewV1
Sourcefn eq(&self, other: &CompositionConflictRuntimeViewV1) -> bool
fn eq(&self, other: &CompositionConflictRuntimeViewV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CompositionConflictRuntimeViewV1