pub struct ContinuityRuntimeViewV1 {
pub schema_version: String,
pub incident_case_id: IncidentCaseId,
pub recovery_plan_id: Option<RecoveryPlanId>,
pub continuity_exception_id: Option<ContinuityExceptionId>,
pub error_budget_ledger_id: Option<ErrorBudgetLedgerId>,
pub replay_completeness: String,
pub degradation_markers: Vec<String>,
}Fields
schema_version: Stringincident_case_id: IncidentCaseIdrecovery_plan_id: Option<RecoveryPlanId>continuity_exception_id: Option<ContinuityExceptionId>error_budget_ledger_id: Option<ErrorBudgetLedgerId>replay_completeness: Stringdegradation_markers: Vec<String>Trait Implementations
Sourceimpl Clone for ContinuityRuntimeViewV1
impl Clone for ContinuityRuntimeViewV1
Sourcefn clone(&self) -> ContinuityRuntimeViewV1
fn clone(&self) -> ContinuityRuntimeViewV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContinuityRuntimeViewV1
impl Debug for ContinuityRuntimeViewV1
Sourceimpl<'de> Deserialize<'de> for ContinuityRuntimeViewV1
impl<'de> Deserialize<'de> for ContinuityRuntimeViewV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContinuityRuntimeViewV1
Sourceimpl JsonSchema for ContinuityRuntimeViewV1
impl JsonSchema for ContinuityRuntimeViewV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ContinuityRuntimeViewV1
impl PartialEq for ContinuityRuntimeViewV1
Sourcefn eq(&self, other: &ContinuityRuntimeViewV1) -> bool
fn eq(&self, other: &ContinuityRuntimeViewV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ContinuityRuntimeViewV1
impl Serialize for ContinuityRuntimeViewV1
impl StructuralPartialEq for ContinuityRuntimeViewV1