pub struct DelegationRuntimeViewV1 {
pub schema_version: String,
pub authority_lease_id: AuthorityLeaseId,
pub validity_state: String,
pub advisory_only: bool,
pub revocation_refs: Vec<String>,
pub missing_backpointers: Vec<String>,
}Fields
schema_version: Stringvalidity_state: Stringadvisory_only: boolrevocation_refs: Vec<String>missing_backpointers: Vec<String>Trait Implementations
Sourceimpl Clone for DelegationRuntimeViewV1
impl Clone for DelegationRuntimeViewV1
Sourcefn clone(&self) -> DelegationRuntimeViewV1
fn clone(&self) -> DelegationRuntimeViewV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DelegationRuntimeViewV1
impl Debug for DelegationRuntimeViewV1
Sourceimpl<'de> Deserialize<'de> for DelegationRuntimeViewV1
impl<'de> Deserialize<'de> for DelegationRuntimeViewV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DelegationRuntimeViewV1
Sourceimpl JsonSchema for DelegationRuntimeViewV1
impl JsonSchema for DelegationRuntimeViewV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DelegationRuntimeViewV1
impl PartialEq for DelegationRuntimeViewV1
Sourcefn eq(&self, other: &DelegationRuntimeViewV1) -> bool
fn eq(&self, other: &DelegationRuntimeViewV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DelegationRuntimeViewV1
impl Serialize for DelegationRuntimeViewV1
impl StructuralPartialEq for DelegationRuntimeViewV1