pub struct DeployabilityRuntimeViewV1 {
pub schema_version: String,
pub deployment_profile_id: DeploymentProfileId,
pub assurance_case_id: AssuranceCaseId,
pub release_readiness_decision_id: Option<ReleaseReadinessDecisionId>,
pub readiness_state: String,
pub advisory_only: bool,
pub open_gaps: Vec<String>,
}Fields
schema_version: Stringdeployment_profile_id: DeploymentProfileIdassurance_case_id: AssuranceCaseIdrelease_readiness_decision_id: Option<ReleaseReadinessDecisionId>readiness_state: Stringadvisory_only: boolopen_gaps: Vec<String>Trait Implementations
Sourceimpl Clone for DeployabilityRuntimeViewV1
impl Clone for DeployabilityRuntimeViewV1
Sourcefn clone(&self) -> DeployabilityRuntimeViewV1
fn clone(&self) -> DeployabilityRuntimeViewV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeployabilityRuntimeViewV1
impl Debug for DeployabilityRuntimeViewV1
Sourceimpl<'de> Deserialize<'de> for DeployabilityRuntimeViewV1
impl<'de> Deserialize<'de> for DeployabilityRuntimeViewV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeployabilityRuntimeViewV1
Sourceimpl JsonSchema for DeployabilityRuntimeViewV1
impl JsonSchema for DeployabilityRuntimeViewV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeployabilityRuntimeViewV1
impl PartialEq for DeployabilityRuntimeViewV1
Sourcefn eq(&self, other: &DeployabilityRuntimeViewV1) -> bool
fn eq(&self, other: &DeployabilityRuntimeViewV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeployabilityRuntimeViewV1