pub struct EffectRuntimeViewV1 {
pub schema_version: String,
pub effect_intent_id: EffectIntentId,
pub effect_window_id: Option<EffectWindowId>,
pub reversibility_class: String,
pub run_mode: String,
pub publication_status: String,
pub degradation_markers: Vec<String>,
}Fields
schema_version: Stringeffect_intent_id: EffectIntentIdeffect_window_id: Option<EffectWindowId>reversibility_class: Stringrun_mode: Stringpublication_status: Stringdegradation_markers: Vec<String>Trait Implementations
Sourceimpl Clone for EffectRuntimeViewV1
impl Clone for EffectRuntimeViewV1
Sourcefn clone(&self) -> EffectRuntimeViewV1
fn clone(&self) -> EffectRuntimeViewV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EffectRuntimeViewV1
impl Debug for EffectRuntimeViewV1
Sourceimpl<'de> Deserialize<'de> for EffectRuntimeViewV1
impl<'de> Deserialize<'de> for EffectRuntimeViewV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EffectRuntimeViewV1
Sourceimpl JsonSchema for EffectRuntimeViewV1
impl JsonSchema for EffectRuntimeViewV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EffectRuntimeViewV1
impl PartialEq for EffectRuntimeViewV1
Sourcefn eq(&self, other: &EffectRuntimeViewV1) -> bool
fn eq(&self, other: &EffectRuntimeViewV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EffectRuntimeViewV1
impl Serialize for EffectRuntimeViewV1
impl StructuralPartialEq for EffectRuntimeViewV1