pub struct EffectiveConstitutionViewV1 {
pub schema_version: String,
pub effective_constitution_id: EffectiveConstitutionId,
pub applicability_context_id: ApplicabilityContextId,
pub profile_set_id: ProfileSetId,
pub mode_classification: String,
pub blocking: bool,
pub approval_requirements: Vec<String>,
pub hard_block_summary: Vec<String>,
pub active_warning_summary: Vec<String>,
pub valid_as_of: String,
pub recorded_as_of: String,
}Fields
schema_version: Stringeffective_constitution_id: EffectiveConstitutionIdapplicability_context_id: ApplicabilityContextIdprofile_set_id: ProfileSetIdmode_classification: Stringblocking: boolapproval_requirements: Vec<String>hard_block_summary: Vec<String>active_warning_summary: Vec<String>valid_as_of: Stringrecorded_as_of: StringTrait Implementations
Sourceimpl Clone for EffectiveConstitutionViewV1
impl Clone for EffectiveConstitutionViewV1
Sourcefn clone(&self) -> EffectiveConstitutionViewV1
fn clone(&self) -> EffectiveConstitutionViewV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EffectiveConstitutionViewV1
impl Debug for EffectiveConstitutionViewV1
Sourceimpl<'de> Deserialize<'de> for EffectiveConstitutionViewV1
impl<'de> Deserialize<'de> for EffectiveConstitutionViewV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EffectiveConstitutionViewV1
Sourceimpl JsonSchema for EffectiveConstitutionViewV1
impl JsonSchema for EffectiveConstitutionViewV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EffectiveConstitutionViewV1
impl PartialEq for EffectiveConstitutionViewV1
Sourcefn eq(&self, other: &EffectiveConstitutionViewV1) -> bool
fn eq(&self, other: &EffectiveConstitutionViewV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EffectiveConstitutionViewV1