pub struct PolicyImpactDiffRuntimeViewV1 {
pub schema_version: String,
pub policy_impact_diff_id: PolicyImpactDiffId,
pub from_effective_constitution_id: EffectiveConstitutionId,
pub to_effective_constitution_id: EffectiveConstitutionId,
pub changed_obligation_families: Vec<String>,
pub newly_blocked_paths: Vec<String>,
pub newly_admitted_paths: Vec<String>,
pub migration_consequences: Vec<String>,
pub simulation_only: bool,
}Fields
schema_version: Stringpolicy_impact_diff_id: PolicyImpactDiffIdfrom_effective_constitution_id: EffectiveConstitutionIdto_effective_constitution_id: EffectiveConstitutionIdchanged_obligation_families: Vec<String>newly_blocked_paths: Vec<String>newly_admitted_paths: Vec<String>migration_consequences: Vec<String>simulation_only: boolTrait Implementations
Sourceimpl Clone for PolicyImpactDiffRuntimeViewV1
impl Clone for PolicyImpactDiffRuntimeViewV1
Sourcefn clone(&self) -> PolicyImpactDiffRuntimeViewV1
fn clone(&self) -> PolicyImpactDiffRuntimeViewV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PolicyImpactDiffRuntimeViewV1
impl<'de> Deserialize<'de> for PolicyImpactDiffRuntimeViewV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PolicyImpactDiffRuntimeViewV1
Sourceimpl JsonSchema for PolicyImpactDiffRuntimeViewV1
impl JsonSchema for PolicyImpactDiffRuntimeViewV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PolicyImpactDiffRuntimeViewV1
impl PartialEq for PolicyImpactDiffRuntimeViewV1
Sourcefn eq(&self, other: &PolicyImpactDiffRuntimeViewV1) -> bool
fn eq(&self, other: &PolicyImpactDiffRuntimeViewV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PolicyImpactDiffRuntimeViewV1